==> maleo_identity-0.0.14-py3-none-any.whl: maleo_identity/models/transfers/parameters/client/user_system_role.py <==
from __future__ import annotations
from maleo_foundation.models.transfers.parameters.client import BaseClientParametersTransfers
from maleo_metadata.models.expanded_schemas.system_role import MaleoMetadataSystemRoleExpandedSchemas
from maleo_identity.models.schemas.general.user_system_role import MaleoIdentityUserSystemRoleGeneralSchemas

class MaleoIdentityUserSystemRoleClientParametersTransfers:
    class GetMultipleFromUser(
        MaleoIdentityUserSystemRoleGeneralSchemas.Expand,
        MaleoMetadataSystemRoleExpandedSchemas.OptionalListOfSimpleSystemRole,
        MaleoIdentityUserSystemRoleGeneralSchemas.UserId,
        BaseClientParametersTransfers.GetPaginatedMultiple
    ): pass
    
    class GetMultiple(
        MaleoIdentityUserSystemRoleGeneralSchemas.Expand,
        MaleoMetadataSystemRoleExpandedSchemas.OptionalListOfSimpleSystemRole,
        MaleoIdentityUserSystemRoleGeneralSchemas.OptionalListOfUserId,
        BaseClientParametersTransfers.GetPaginatedMultiple
    ): pass

    class GetMultipleFromUserQuery(
        MaleoIdentityUserSystemRoleGeneralSchemas.Expand,
        MaleoMetadataSystemRoleExpandedSchemas.OptionalListOfSimpleSystemRole,
        BaseClientParametersTransfers.GetPaginatedMultipleQuery
    ): pass

    class GetMultipleQuery(
        MaleoIdentityUserSystemRoleGeneralSchemas.Expand,
        MaleoMetadataSystemRoleExpandedSchemas.OptionalListOfSimpleSystemRole,
        MaleoIdentityUserSystemRoleGeneralSchemas.OptionalListOfUserId,
        BaseClientParametersTransfers.GetPaginatedMultipleQuery
    ): pass

==> maleo_identity-0.0.32-py3-none-any.whl: maleo_identity/models/transfers/parameters/client/user_system_role.py <==
from __future__ import annotations
from maleo_foundation.models.transfers.parameters.client import BaseClientParametersTransfers
from maleo_metadata.models.expanded_schemas.system_role import MaleoMetadataSystemRoleExpandedSchemas
from maleo_identity.models.schemas.general.user_system_role import MaleoIdentityUserSystemRoleGeneralSchemas

class MaleoIdentityUserSystemRoleClientParametersTransfers:
    class GetMultipleFromUser(
        MaleoIdentityUserSystemRoleGeneralSchemas.Expand,
        BaseClientParametersTransfers.GetPaginatedMultiple,
        MaleoMetadataSystemRoleExpandedSchemas.OptionalListOfSimpleSystemRole,
        MaleoIdentityUserSystemRoleGeneralSchemas.UserId
    ): pass
    
    class GetMultiple(
        MaleoIdentityUserSystemRoleGeneralSchemas.Expand,
        BaseClientParametersTransfers.GetPaginatedMultiple,
        MaleoMetadataSystemRoleExpandedSchemas.OptionalListOfSimpleSystemRole,
        MaleoIdentityUserSystemRoleGeneralSchemas.OptionalListOfUserId
    ): pass

    class GetMultipleFromUserQuery(
        MaleoIdentityUserSystemRoleGeneralSchemas.Expand,
        BaseClientParametersTransfers.GetPaginatedMultipleQuery,
        MaleoMetadataSystemRoleExpandedSchemas.OptionalListOfSimpleSystemRole
    ): pass

    class GetMultipleQuery(
        MaleoIdentityUserSystemRoleGeneralSchemas.Expand,
        BaseClientParametersTransfers.GetPaginatedMultipleQuery,
        MaleoMetadataSystemRoleExpandedSchemas.OptionalListOfSimpleSystemRole,
        MaleoIdentityUserSystemRoleGeneralSchemas.OptionalListOfUserId
    ): pass
